ApiClient class

Constructors

ApiClient({String basePath = 'https://raw.githubusercontent.com/api/v2'})

Properties

authentications → Map<String, Authentication>
Returns an unmodifiable Map of the authentications, since none should be added or deleted.
no setter
basePath → String
final
client ↔ Client
The HTTP Client instance to use in this class.
getter/setter pair
defaultHeaderMap → Map<String, String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addDefaultHeader(String key, String value) → void
deserialize(String? json, String targetType, {bool? growable}) → dynamic
deserializeAsync(String? json, String targetType, {bool? growable}) → Future
getAuthentication<T extends Authentication>(String name) → T?
invokeAPI(String path, String method, List<QueryParam> queryParams, Object? body, Map<String, String> headerParams, Map<String, String> formParams, String? nullableContentType, List<String> authNames) → Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(Object? value) → String
serializeAsync(Object? value) → Future<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited