Authorization class

Constructors

Authorization({AuthorizationStatusEnum? status = const AuthorizationStatusEnum._('active'), String? description, DateTime? createdAt, DateTime? updatedAt, required String? orgID, List<Permission>? permissions = const [], String? id, String? token, String? userID, String? user, String? org, AuthorizationAllOfLinks? links})
Returns a new Authorization instance.

Properties

createdAt ↔ DateTime?
getter/setter pair
description ↔ String?
A description of the token.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
getter/setter pair
getter/setter pair
org ↔ String?
Name of the org token is scoped to.
getter/setter pair
orgID ↔ String?
ID of org that authorization is scoped to.
getter/setter pair
permissions ↔ List<Permission>?
List of permissions for an auth. An auth must have at least one Permission.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ AuthorizationStatusEnum?
If inactive the token is inactive and requests using the token will be rejected.
getter/setter pair
token ↔ String?
Passed via the Authorization Header and Token Authentication type.
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair
user ↔ String?
Name of user that created and owns the token.
getter/setter pair
userID ↔ String?
ID of user that created and owns the token.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → Authorization
Returns a new Authorization instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<Authorization>?
mapFromJson(dynamic json) → Map<String, Authorization?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<Authorization?>?>