AuthorizationPostRequest class

Constructors

AuthorizationPostRequest({AuthorizationPostRequestStatusEnum? status = const AuthorizationPostRequestStatusEnum._('active'), String? description, required String? orgID, String? userID, List<Permission>? permissions = const []})
Returns a new AuthorizationPostRequest instance.

Properties

description ↔ String?
A description of the token.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
orgID ↔ String?
ID of org that authorization is scoped to.
getter/setter pair
permissions ↔ List<Permission>?
List of permissions for an auth. An auth must have at least one Permission.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ AuthorizationPostRequestStatusEnum?
If inactive the token is inactive and requests using the token will be rejected.
getter/setter pair
userID ↔ String?
ID of user that authorization is scoped to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → AuthorizationPostRequest
Returns a new AuthorizationPostRequest instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<AuthorizationPostRequest>?
mapFromJson(dynamic json) → Map<String, AuthorizationPostRequest?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<AuthorizationPostRequest?>?>