Authorizations class

Constructors

Authorizations({Links? links, List<Authorization?>? authorizations = const []})
Returns a new Authorizations instance.

Properties

authorizations ↔ List<Authorization?>?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) → Authorizations?
Returns a new Authorizations instance and imports its values from json if it's non-null, null if json is null.
listFromJson(List json, {bool? emptyIsNull, bool? growable}) → List<Authorizations?>?
mapFromJson(Map<String, dynamic> json) → Map<String, Authorizations?>
mapListFromJson(Map<String, dynamic> json, {bool? emptyIsNull, bool? growable}) → Map<String, List<Authorizations?>?>