BucketTypeEnum class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) → BucketTypeEnum?
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<BucketTypeEnum?>?

Constants

system → const BucketTypeEnum
user → const BucketTypeEnum
values → const List<BucketTypeEnum>
List of all possible values in this BucketTypeEnum.