Buckets class

Constructors

Buckets({Links? links, List<Bucket>? buckets = const []})
Returns a new Buckets instance.

Properties

buckets ↔ List<Bucket>?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → Buckets
Returns a new Buckets instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<Buckets>?
mapFromJson(dynamic json) → Map<String, Buckets?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<Buckets?>?>