DefaultService class abstract

Superclass for all services.

Implementers

Constructors

DefaultService(InfluxDBClient influxDB)

Properties

apiClient ↔ ApiClient
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
influxDB → InfluxDBClient
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getApiClient(String basePath) → ApiClient?
getClient() → Client?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited