DeletePredicateRequest class

Constructors

DeletePredicateRequest({required DateTime? start, required DateTime? stop, String? predicate})
Returns a new DeletePredicateRequest instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
predicate ↔ String?
InfluxQL-like delete statement
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ DateTime?
RFC3339Nano
getter/setter pair
stop ↔ DateTime?
RFC3339Nano
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → DeletePredicateRequest
Returns a new DeletePredicateRequest instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<DeletePredicateRequest>?
mapFromJson(dynamic json) → Map<String, DeletePredicateRequest?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<DeletePredicateRequest?>?>