FluxTableMetaData class

Represents metadata of a {@link http://bit.ly/flux-spec#table | flux table}.

Constructors

FluxTableMetaData(int tableIndex)

Properties

columns ↔ List<FluxColumn>
Table columns.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableIndex ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toObject(List values) → FluxRecord
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited