InfluxDBException class

Implemented types

Constructors

InfluxDBException(int statusCode, String? code, String? message, {int? retryAfter = -1})

Properties

code ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pair
retryAfter ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(String errorBody, int statusCode, Map<String, String> headers) → InfluxDBException
fromResponse(BaseResponse response) → InfluxDBException