LabelResponse class

Constructors

LabelResponse({Label? label, Links? links})
Returns a new LabelResponse instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
label ↔ Label?
getter/setter pair
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → LabelResponse
Returns a new LabelResponse instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<LabelResponse>?
mapFromJson(dynamic json) → Map<String, LabelResponse?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<LabelResponse?>?>