LabelsResponse class

Constructors

LabelsResponse({List<Label>? labels = const [], Links? links})
Returns a new LabelsResponse instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
labels ↔ List<Label>?
getter/setter pair
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → LabelsResponse
Returns a new LabelsResponse instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<LabelsResponse>?
mapFromJson(dynamic json) → Map<String, LabelsResponse?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<LabelsResponse?>?>