Logs class

Constructors

Logs({List<LogEvent>? events = const []})
Returns a new Logs instance.

Properties

events ↔ List<LogEvent>?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → Logs
Returns a new Logs instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<Logs>?
mapFromJson(dynamic json) → Map<String, Logs?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<Logs?>?>