OnboardingRequest class

Constructors

OnboardingRequest({required String? username, String? password, required String? org, required String? bucket, int? retentionPeriodSeconds, int? retentionPeriodHrs, String? token})
Returns a new OnboardingRequest instance.

Properties

bucket ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
org ↔ String?
getter/setter pair
password ↔ String?
getter/setter pair
retentionPeriodHrs ↔ int?
Retention period in nanoseconds for the new bucket. This key's name has been misleading since OSS 2.0 GA, please transition to use retentionPeriodSeconds
getter/setter pair
retentionPeriodSeconds ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String?
Authentication token to set on the initial user. If not specified, the server will generate a token.
getter/setter pair
username ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → OnboardingRequest
Returns a new OnboardingRequest instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<OnboardingRequest>?
mapFromJson(dynamic json) → Map<String, OnboardingRequest?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<OnboardingRequest?>?>