PasswordResetBody class

Constructors

PasswordResetBody({required String? password})
Returns a new PasswordResetBody instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
password ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → PasswordResetBody
Returns a new PasswordResetBody instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<PasswordResetBody>?
mapFromJson(dynamic json) → Map<String, PasswordResetBody?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<PasswordResetBody?>?>