PatchOrganizationRequest class

Constructors

PatchOrganizationRequest({String? name, String? description})
Returns a new PatchOrganizationRequest instance.

Properties

description ↔ String?
New description to set on the organization
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
name ↔ String?
New name to set on the organization
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → PatchOrganizationRequest
Returns a new PatchOrganizationRequest instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<PatchOrganizationRequest>?
mapFromJson(dynamic json) → Map<String, PatchOrganizationRequest?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<PatchOrganizationRequest?>?>