Query class

Constructors

Query({File? extern, required String? query, QueryTypeEnum? type, Map<String, Object>? params = const {}, Dialect? dialect, DateTime? now})
Returns a new Query instance.

Properties

dialect ↔ Dialect?
getter/setter pair
extern ↔ File?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
now ↔ DateTime?
Specifies the time that should be reported as "now" in the query. Default is the server's now time.
getter/setter pair
params ↔ Map<String, Object>?
Enumeration of key/value pairs that respresent parameters to be injected into query (can only specify either this field or extern and not both)
getter/setter pair
query ↔ String?
Query script to execute.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ QueryTypeEnum?
The type of query. Must be "flux".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) → Query?
Returns a new Query instance and imports its values from json if it's non-null, null if json is null.
listFromJson(List json, {bool? emptyIsNull, bool? growable}) → List<Query?>?
mapFromJson(Map<String, dynamic> json) → Map<String, Query?>
mapListFromJson(Map<String, dynamic> json, {bool? emptyIsNull, bool? growable}) → Map<String, List<Query?>?>