QueryService class

Query InfluxDB 2.x. Provides methods for stream Flux query. See {@link https://docs.influxdata.com/influxdb/latest/api/#operation/PostQuery }

Inheritance

Constructors

QueryService(InfluxDBClient client, {QueryOptions? queryOptions})

Properties

apiClient ↔ ApiClient
getter/setter pairinherited
gzip ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
influxDB → InfluxDBClient
finalinherited
queryApi ↔ QueryApi?
getter/setter pair
queryOptions ↔ QueryOptions
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getApiClient(String basePath) → ApiClient?
inherited
getClient() → Client?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(dynamic fluxQuery, {Map<String, Object>? params}) → Future<Stream<FluxRecord>>
Streams the result of query into Stream<FluxRecord>
queryLines(dynamic fluxQuery, {Dialect? dialect, Map<String, Object>? params}) → Future<Stream<List>>
Streams the result of fluxQuery using Dialect.
queryRaw(dynamic fluxQuery, {Dialect? dialect, Map<String, Object>? params}) → Future<String>
Gets the result of fluxQuery as a raw string.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited