Ready class

Constructors

Ready({ReadyStatusEnum? status, DateTime? started, String? up})
Returns a new Ready instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
started ↔ DateTime?
getter/setter pair
status ↔ ReadyStatusEnum?
getter/setter pair
up ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → Ready
Returns a new Ready instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<Ready>?
mapFromJson(dynamic json) → Map<String, Ready?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<Ready?>?>