RunLinks class

Constructors

RunLinks({String? self, String? task, String? retry})
Returns a new RunLinks instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
retry ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
self ↔ String?
getter/setter pair
task ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → RunLinks
Returns a new RunLinks instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<RunLinks>?
mapFromJson(dynamic json) → Map<String, RunLinks?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<RunLinks?>?>