RunManually class

Constructors

RunManually({DateTime? scheduledFor})
Returns a new RunManually instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledFor ↔ DateTime?
Time used for run's "now" option, RFC3339. Default is the server's now time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → RunManually
Returns a new RunManually instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<RunManually>?
mapFromJson(dynamic json) → Map<String, RunManually?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<RunManually?>?>