Scripts class

Constructors

Scripts({List<Script>? scripts = const []})
Returns a new Scripts instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scripts ↔ List<Script>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → Scripts
Returns a new Scripts instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<Scripts>?
mapFromJson(dynamic json) → Map<String, Scripts?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<Scripts?>?>