SecretKeys class

Constructors

SecretKeys({List<String>? secrets = const []})
Returns a new SecretKeys instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secrets ↔ List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → SecretKeys
Returns a new SecretKeys instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<SecretKeys>?
mapFromJson(dynamic json) → Map<String, SecretKeys?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<SecretKeys?>?>