Task class

Constructors

Task({required String? id, String? type, required String? orgID, String? org, required String? name, String? ownerID, String? description, TaskStatusType? status, List<Label>? labels = const [], String? authorizationID, required String? flux, String? every, String? cron, String? offset, DateTime? latestCompleted, TaskLastRunStatusEnum? lastRunStatus, String? lastRunError, DateTime? createdAt, DateTime? updatedAt, TaskLinks? links})
Returns a new Task instance.

Properties

authorizationID ↔ String?
The ID of the authorization used when this task communicates with the query engine.
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
cron ↔ String?
A task repetition schedule in the form '* * * * * *'; parsed from Flux.
getter/setter pair
description ↔ String?
An optional description of the task.
getter/setter pair
every ↔ String?
A simple task repetition schedule; parsed from Flux.
getter/setter pair
flux ↔ String?
The Flux script to run for this task.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
getter/setter pair
labels ↔ List<Label>?
getter/setter pair
lastRunError ↔ String?
getter/setter pair
lastRunStatus ↔ TaskLastRunStatusEnum?
getter/setter pair
latestCompleted ↔ DateTime?
Timestamp of latest scheduled, completed run, RFC3339.
getter/setter pair
getter/setter pair
name ↔ String?
The name of the task.
getter/setter pair
offset ↔ String?
Duration to delay after the schedule, before executing the task; parsed from flux, if set to zero it will remove this option and use 0 as the default.
getter/setter pair
org ↔ String?
The name of the organization that owns this Task.
getter/setter pair
orgID ↔ String?
The ID of the organization that owns this Task.
getter/setter pair
ownerID ↔ String?
The ID of the user who owns this Task.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ TaskStatusType?
getter/setter pair
type ↔ String?
The type of task, this can be used for filtering tasks on list actions.
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → Task
Returns a new Task instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<Task>?
mapFromJson(dynamic json) → Map<String, Task?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<Task?>?>