UserResponse class

Constructors

UserResponse({String? id, String? oauthID, required String? name, UserResponseStatusEnum? status = const UserResponseStatusEnum._('active'), UserResponseLinks? links})
Returns a new UserResponse instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
getter/setter pair
getter/setter pair
name ↔ String?
getter/setter pair
oauthID ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ UserResponseStatusEnum?
If inactive the user is inactive.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → UserResponse
Returns a new UserResponse instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<UserResponse>?
mapFromJson(dynamic json) → Map<String, UserResponse?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<UserResponse?>?>