UsersApi class

Constructors

UsersApi(ApiClient apiClient)

Properties

apiClient → ApiClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteUsersID(String userID, {String? zapTraceSpan}) → Future<void>
Delete a user
deleteUsersIDWithHttpInfo(String userID, {String? zapTraceSpan}) → Future<Response>
Delete a user
getFlags({String? zapTraceSpan}) → Future<Map<String, Object>>
Return the feature flags for the currently authenticated user
getFlagsWithHttpInfo({String? zapTraceSpan}) → Future<Response>
Return the feature flags for the currently authenticated user
getMe({String? zapTraceSpan}) → Future<UserResponse>
Retrieve the currently authenticated user
getMeWithHttpInfo({String? zapTraceSpan}) → Future<Response>
Retrieve the currently authenticated user
getUsers({String? zapTraceSpan, int? offset, int? limit, String? after, String? name, String? id}) → Future<Users>
List all users
getUsersID(String userID, {String? zapTraceSpan}) → Future<UserResponse>
Retrieve a user
getUsersIDWithHttpInfo(String userID, {String? zapTraceSpan}) → Future<Response>
Retrieve a user
getUsersWithHttpInfo({String? zapTraceSpan, int? offset, int? limit, String? after, String? name, String? id}) → Future<Response>
List all users
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchUsersID(String userID, User user, {String? zapTraceSpan}) → Future<UserResponse>
Update a user
patchUsersIDWithHttpInfo(String userID, User user, {String? zapTraceSpan}) → Future<Response>
Update a user
postUsers(User user, {String? zapTraceSpan}) → Future<UserResponse>
Create a user
postUsersIDPassword(String userID, PasswordResetBody passwordResetBody, {String? zapTraceSpan}) → Future<void>
Update a password
postUsersIDPasswordWithHttpInfo(String userID, PasswordResetBody passwordResetBody, {String? zapTraceSpan}) → Future<Response>
Update a password
postUsersWithHttpInfo(User user, {String? zapTraceSpan}) → Future<Response>
Create a user
putMePassword(PasswordResetBody passwordResetBody, {String? zapTraceSpan}) → Future<void>
Update a password
putMePasswordWithHttpInfo(PasswordResetBody passwordResetBody, {String? zapTraceSpan}) → Future<Response>
Update a password
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited