Variable class

Constructors

Variable({VariableLinks? links, String? id, required String? orgID, required String? name, String? description, List<String>? selected = const [], List<Label>? labels = const [], required VariableProperties? arguments, DateTime? createdAt, DateTime? updatedAt})
Returns a new Variable instance.

Properties

arguments ↔ VariableProperties?
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
getter/setter pair
labels ↔ List<Label>?
getter/setter pair
getter/setter pair
name ↔ String?
getter/setter pair
orgID ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected ↔ List<String>?
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → Variable
Returns a new Variable instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<Variable>?
mapFromJson(dynamic json) → Map<String, Variable?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<Variable?>?>