VariableProperties class

Constructors

VariableProperties({VariablePropertiesTypeEnum? type, Map<String, String>? values = const {}})
Returns a new VariableProperties instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ VariablePropertiesTypeEnum?
getter/setter pair
values ↔ Map<String, String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → VariableProperties
Returns a new VariableProperties instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<VariableProperties>?
mapFromJson(dynamic json) → Map<String, VariableProperties?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<VariableProperties?>?>