Variables class

Constructors

Variables({List<Variable>? variables = const []})
Returns a new Variables instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variables ↔ List<Variable>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → Variables
Returns a new Variables instance and imports
listFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → List<Variables>?
mapFromJson(dynamic json) → Map<String, Variables?>
mapListFromJson(dynamic json, {bool? emptyIsNull, bool? growable}) → Map<String, List<Variables?>?>