WriteOptions class

Options used by WriteApi .

Constructors

WriteOptions({int batchSize = 1000, int flushInterval = 1000, int retryJitter = 200, int retryInterval = 5000, int maxRetryDelay = 125000, int maxRetryTime = 180000, int exponentialBase = 2, int maxRetries = 5, int maxBufferLines = 100000, Map<String, String>? defaultTags, WritePrecision precision = WritePrecision.ns, bool gzip = false})

Properties

batchSize → int
max number of records to send in a batch
final
defaultTags → Map<String, String>?
default tags, unescaped */
final
exponentialBase → int
base for the exponential retry delay (default is 2)
final
flushInterval → int
delay between data flushes in milliseconds, at most batch size records are sent during flush */
final
gzip ↔ bool
Enable gzip compression
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxBufferLines → int
the maximum size of retry-buffer (in lines)
final
maxRetries → int
max number of retries when write fails (default is 5)
final
maxRetryDelay → int
maximum delay when retrying write (milliseconds, default is 125000)
final
maxRetryTime → int
maximum time for retrying write (milliseconds, default is 180000)
final
precision → WritePrecision
default precision
final
retryInterval → int
delay when retrying first write (milliseconds, default is 5000)
final
retryJitter → int
include random milliseconds when retrying HTTP calls (default is 200)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

merge({int? batchSize, int? flushInterval, Map<String, String>? defaultTags, int? retryJitter, int? retryInterval, int? maxRetryDelay, int? maxRetryTime, int? exponentialBase, int? maxRetries, int? maxBufferLines, WritePrecision? precision, bool? gzip}) → WriteOptions
Create a WriteOptions from current instance with merging attributes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRetryStrategy() → RetryOptions
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited